/**
 * External dependencies
 */
var React = require( 'react' ),
	debug = require( 'debug' )( 'calypso:my-sites:site-settings:security:monitor' );

/**
 * Internal dependencies
 */
var config = require( 'config' ),
	protectForm = require( 'lib/mixins/protect-form' ),
	Card = require( 'components/card' ),
	FormSectionHeading = require( 'components/forms/form-section-heading' ),
	FormButton = require( 'components/forms/form-button' ),
	FormCheckbox = require( 'components/forms/form-checkbox' ),
	FormLabel = require( 'components/forms/form-label' ),
	formBase = require( './form-base' ),
	SettingsCardFooter = require( './settings-card-footer' ),
	notices = require( 'notices' ),
	dirtyLinkedState = require( 'lib/mixins/dirty-linked-state' );

module.exports = React.createClass( {

	displayName: 'SiteSettingsFormJetpackMonitor',

	mixins: [ dirtyLinkedState, protectForm.mixin, formBase ],

	getSettingsFromSite: function( site ) {
		var settings = {};

		site = site || this.props.site;
		settings.fetchingSettings = site.fetchingSettings;

		return settings;
	},

	resetState: function() {
		this.replaceState( {
			togglingModule: false,
			emailNotifications: false
		} );
	},

	getModuleStatus: function( site ) {
		site = site || this.props.site;

		site.fetchMonitorSettings( ( function( error, data ) {
			if ( ! error ) {
				this.setState( {
					emailNotifications: data.settings.email_notifications
				} );
			} else {
				debug( 'error getting Monitor settings', error );
			}
		} ).bind( this ) );

		site.verifyModulesActive( [ 'monitor' ], ( function( error, moduleStatus ) {
			if ( ! error ) {
				this.setState( { enabled: moduleStatus } );
			} else {
				debug( 'error getting module status', error );
			}
		} ).bind( this ) );
	},

	prompt: function() {
		return (
			<div>
				<p>{ this.translate( "Automatically monitor your website and make sure it's online." ) }</p>
				<p>
					{ this.translate(
						"We'll periodically check your site from our global network of servers to make sure it's online, and email you if it looks like your site is not responding for any reason."
					) }
				</p>
				<SettingsCardFooter>
					<FormButton
						onClick={ this.toggleJetpackModule.bind( this, 'monitor' ) }
						disabled={ this.disableForm() }
					>
						{ this.state.togglingModule ? this.translate( 'Activating…' ) : this.translate( 'Activate Monitor' ) }
					</FormButton>
				</SettingsCardFooter>
			</div>
		);
	},

	saveSettings: function() {
		this.setState( { submitingForm: true } );
		notices.clearNotices( 'notices' );
		this.props.site.updateMonitorSettings( this.state.emailNotifications, ( function( error ) {
			if ( error ) {
				this.handleError();
				notices.error( this.translate( 'There was a problem saving your changes. Please, try again.' ) );
				return;
			}
			notices.success( this.translate( 'Settings saved successfully!' ) );
			this.markSaved();
			this.setState( { submittingForm: false } );
		} ).bind( this ) );
	},

	settings: function() {
		return (
			<div>
				<p>{ this.translate( "Jetpack is currently monitoring your site's uptime." ) }</p>
				<FormLabel>
					<FormCheckbox
						disabled={ this.disableForm() }
						onClick={ this.recordEvent.bind( this, 'Clicked on Monitor email checkbox' ) }
						id="jetpack_monitor_email"
						checkedLink={ this.linkState( 'emailNotifications' ) }
						name="jetpack_monitor_email" />
					<span>
						{ this.translate( 'Send notifications to your {{a}}WordPress.com email address{{/a}}.', {
							components: {
								a: <a href="/me/account" onClick={ this.recordEvent.bind( this, 'Clicked on Monitor Link to WordPress.com Email Address' ) } />
							}
						} ) }
					</span>
				</FormLabel>

				<SettingsCardFooter>
					<FormButton disabled={ this.disableForm() } onClick={ this.saveSettings }>
						{ this.state.submittingForm ? this.translate( 'Saving…' ) : this.translate( 'Save Settings' ) }
					</FormButton>
					<FormButton
						disabled={ this.disableForm() }
						className="jetpack-monitor__deactivate is-link"
						isPrimary={ false }
						onClick={ this.toggleJetpackModule.bind( this, 'monitor' ) } >
						{ this.state.togglingModule ? this.translate( 'Deactivating…' ) : this.translate( 'Deactivate' ) }
					</FormButton>
				</SettingsCardFooter>
			</div>
		);
	},

	// updates the state when an error occurs
	handleError: function() {
		this.setState( { submittingForm : false, togglingModule: false } );
		this.markSaved();
	},

	disableForm: function() {
		return this.state.fetchingSettings || this.state.submittingForm || this.props.site.fetchingModules || this.state.togglingModule;
	},

	render: function() {
		if ( ! config.isEnabled( 'settings/security/monitor' ) ) {
			return null;
		}

		return (
			<Card className="jetpack-monitor-settings">
				<FormSectionHeading>{ this.translate( 'Jetpack Monitor' ) }</FormSectionHeading>
				{
					( this.state.enabled ) ?
					this.settings() :
					this.prompt()
				}
			</Card>
		);
	}

} );
